==> resiprocate_1.9.7.orig.tar.gz: resiprocate-1.9.7/resip/dum/ChallengeInfo.cxx <==

#include <cassert>

#include "resip/dum/ChallengeInfo.hxx"
#include "rutil/Data.hxx"
#include "rutil/Logger.hxx"

using namespace resip;
using namespace std;

#define RESIPROCATE_SUBSYSTEM Subsystem::DUM


ChallengeInfo::ChallengeInfo( bool failed,
                              bool challengeRequired,
                              const Data& transactionId ):
   DumFeatureMessage(transactionId),
   mFailed(failed),
   mChallengeRequired(challengeRequired)
{
}

ChallengeInfo::~ChallengeInfo()
{
}

bool
ChallengeInfo::isFailed() const
{
   return mFailed;
}

bool
ChallengeInfo::isChallengeRequired() const
{
   return mChallengeRequired;
}

Data
ChallengeInfo::brief() const
{
   Data buffer;
   DataStream strm(buffer);
   strm << "ChallengeInfo " << mFailed << " : " << mChallengeRequired;
   strm.flush();
   return buffer;
}

resip::Message*
ChallengeInfo::clone() const
{
   assert(false); return NULL;
}

std::ostream&
ChallengeInfo::encode(std::ostream& strm) const
{
   strm << brief();
   return strm;
}

std::ostream&
ChallengeInfo::encodeBrief(std::ostream& strm) const
{
   return encode(strm);
}

std::ostream&
resip::operator<<(std::ostream& strm, const ChallengeInfo& msg)
{
   return msg.encode(strm);
}

/* ====================================================================
 * The Vovida Software License, Version 1.0
 *
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 *
 * ====================================================================
 *
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

==> resiprocate_1.10.1.orig.tar.gz: resiprocate-1.10.1/resip/dum/ChallengeInfo.cxx <==

#include "rutil/ResipAssert.h"

#include "resip/dum/ChallengeInfo.hxx"
#include "rutil/Data.hxx"
#include "rutil/Logger.hxx"

using namespace resip;
using namespace std;

#define RESIPROCATE_SUBSYSTEM Subsystem::DUM


ChallengeInfo::ChallengeInfo( bool failed,
                              bool challengeRequired,
                              const Data& transactionId ):
   DumFeatureMessage(transactionId),
   mFailed(failed),
   mChallengeRequired(challengeRequired)
{
}

ChallengeInfo::~ChallengeInfo()
{
}

bool
ChallengeInfo::isFailed() const
{
   return mFailed;
}

bool
ChallengeInfo::isChallengeRequired() const
{
   return mChallengeRequired;
}

Data
ChallengeInfo::brief() const
{
   Data buffer;
   DataStream strm(buffer);
   strm << "ChallengeInfo " << mFailed << " : " << mChallengeRequired;
   strm.flush();
   return buffer;
}

resip::Message*
ChallengeInfo::clone() const
{
   resip_assert(false); return NULL;
}

std::ostream&
ChallengeInfo::encode(std::ostream& strm) const
{
   strm << brief();
   return strm;
}

std::ostream&
ChallengeInfo::encodeBrief(std::ostream& strm) const
{
   return encode(strm);
}

std::ostream&
resip::operator<<(std::ostream& strm, const ChallengeInfo& msg)
{
   return msg.encode(strm);
}

/* ====================================================================
 * The Vovida Software License, Version 1.0
 *
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 *
 * ====================================================================
 *
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */
